jaclearn.imageaug.cblk
======================

.. automodule:: jaclearn.imageaug.cblk

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      fbaug
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: fbaug


